All of lore.kernel.org
 help / color / mirror / Atom feed
* [PATCH mptcp-next] Squash to "selftests/bpf: Add mptcp subflow subtest" - set limits
@ 2024-07-30  8:24 Geliang Tang
  2024-07-30  9:04 ` Matthieu Baerts
  2024-07-30  9:15 ` MPTCP CI
  0 siblings, 2 replies; 4+ messages in thread
From: Geliang Tang @ 2024-07-30  8:24 UTC (permalink / raw)
  To: mptcp; +Cc: Geliang Tang

From: Geliang Tang <tanggeliang@kylinos.cn>

Need to set limits before adding endpoints.

Signed-off-by: Geliang Tang <tanggeliang@kylinos.cn>
---
 tools/testing/selftests/bpf/prog_tests/mptcp.c | 5 ++++-
 1 file changed, 4 insertions(+), 1 deletion(-)

diff --git a/tools/testing/selftests/bpf/prog_tests/mptcp.c b/tools/testing/selftests/bpf/prog_tests/mptcp.c
index 00f63f3f19f4..ffc2cfacabee 100644
--- a/tools/testing/selftests/bpf/prog_tests/mptcp.c
+++ b/tools/testing/selftests/bpf/prog_tests/mptcp.c
@@ -357,9 +357,12 @@ static int endpoint_init(char *flags)
 	SYS(fail, "ip -net %s link set dev veth1 up", NS_TEST);
 	SYS(fail, "ip -net %s addr add %s/24 dev veth2", NS_TEST, ADDR_2);
 	SYS(fail, "ip -net %s link set dev veth2 up", NS_TEST);
 	/* It would be better to use  "ip -net %s mptcp endpoint add %s %s",
 	 * but the BPF CI is using an old version of IPRoute (5.5.0).
 	 */
+	SYS(fail, "ip netns exec %s ./mptcp_pm_nl_ctl limits 8 8", NS_TEST);
 	SYS(fail, "ip netns exec %s ./mptcp_pm_nl_ctl add %s flags %s", NS_TEST, ADDR_2, flags);
 
 	return 0;
@@ -357,9 +357,12 @@ static int endpoint_init(char *flags)
 	SYS(fail, "ip -net %s addr add %s/24 dev veth2", NS_TEST, ADDR_2);
 	SYS(fail, "ip -net %s link set dev veth2 up", NS_TEST);
-	/* It would be better to use  "ip -net %s mptcp endpoint add %s %s",
+	/* It would be better to use
+	 *	ip -net %s mptcp limits set add_addr_accepted 8 subflows 8
+	 *	ip -net %s mptcp endpoint add %s %s
 	 * but the BPF CI is using an old version of IPRoute (5.5.0).
 	 */
-- 
2.43.0


^ permalink raw reply related	[flat|nested] 4+ messages in thread

* Re: [PATCH mptcp-next] Squash to "selftests/bpf: Add mptcp subflow subtest" - set limits
  2024-07-30  8:24 [PATCH mptcp-next] Squash to "selftests/bpf: Add mptcp subflow subtest" - set limits Geliang Tang
@ 2024-07-30  9:04 ` Matthieu Baerts
  2024-07-30  9:14   ` Geliang Tang
  2024-07-30  9:15 ` MPTCP CI
  1 sibling, 1 reply; 4+ messages in thread
From: Matthieu Baerts @ 2024-07-30  9:04 UTC (permalink / raw)
  To: Geliang Tang, mptcp; +Cc: Geliang Tang

Hi Geliang,

On 30/07/2024 10:24, Geliang Tang wrote:
> From: Geliang Tang <tanggeliang@kylinos.cn>
> 
> Need to set limits before adding endpoints.

Why do we need to do that? Do we not have 2 subflows in these tests?
The default limits are set at 2 additional subflows, is it not enough?

Cheers,
Matt
-- 
Sponsored by the NGI0 Core fund.


^ permalink raw reply	[flat|nested] 4+ messages in thread

* Re: [PATCH mptcp-next] Squash to "selftests/bpf: Add mptcp subflow subtest" - set limits
  2024-07-30  9:04 ` Matthieu Baerts
@ 2024-07-30  9:14   ` Geliang Tang
  0 siblings, 0 replies; 4+ messages in thread
From: Geliang Tang @ 2024-07-30  9:14 UTC (permalink / raw)
  To: Matthieu Baerts, mptcp; +Cc: Geliang Tang

On Tue, 2024-07-30 at 11:04 +0200, Matthieu Baerts wrote:
> Hi Geliang,
> 
> On 30/07/2024 10:24, Geliang Tang wrote:
> > From: Geliang Tang <tanggeliang@kylinos.cn>
> > 
> > Need to set limits before adding endpoints.
> 
> Why do we need to do that? Do we not have 2 subflows in these tests?
> The default limits are set at 2 additional subflows, is it not
> enough?

I thought the default value was 0. Indeed, subflows_max is set to 2 in
pm_nl_init_net(). It's enough for this test then.

Thanks,
-Geliang

> 
> Cheers,
> Matt


^ permalink raw reply	[flat|nested] 4+ messages in thread

* Re: [PATCH mptcp-next] Squash to "selftests/bpf: Add mptcp subflow subtest" - set limits
  2024-07-30  8:24 [PATCH mptcp-next] Squash to "selftests/bpf: Add mptcp subflow subtest" - set limits Geliang Tang
  2024-07-30  9:04 ` Matthieu Baerts
@ 2024-07-30  9:15 ` MPTCP CI
  1 sibling, 0 replies; 4+ messages in thread
From: MPTCP CI @ 2024-07-30  9:15 UTC (permalink / raw)
  To: Geliang Tang; +Cc: mptcp

Hi Geliang,

Thank you for your modifications, that's great!

Our CI did some validations and here is its report:

- KVM Validation: normal: Success! ✅
- KVM Validation: debug: Success! ✅
- KVM Validation: btf (only bpftest_all): Success! ✅
- Task: https://github.com/multipath-tcp/mptcp_net-next/actions/runs/10159055388

Initiator: Patchew Applier
Commits: https://github.com/multipath-tcp/mptcp_net-next/commits/46124ffdcd41
Patchwork: https://patchwork.kernel.org/project/mptcp/list/?series=874969


If there are some issues, you can reproduce them using the same environment as
the one used by the CI thanks to a docker image, e.g.:

    $ cd [kernel source code]
    $ docker run -v "${PWD}:${PWD}:rw" -w "${PWD}" --privileged --rm -it \
        --pull always mptcp/mptcp-upstream-virtme-docker:latest \
        auto-normal

For more details:

    https://github.com/multipath-tcp/mptcp-upstream-virtme-docker


Please note that despite all the efforts that have been already done to have a
stable tests suite when executed on a public CI like here, it is possible some
reported issues are not due to your modifications. Still, do not hesitate to
help us improve that ;-)

Cheers,
MPTCP GH Action bot
Bot operated by Matthieu Baerts (NGI0 Core)

^ permalink raw reply	[flat|nested] 4+ messages in thread

end of thread, other threads:[~2024-07-30  9:15 UTC | newest]

Thread overview: 4+ messages (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
2024-07-30  8:24 [PATCH mptcp-next] Squash to "selftests/bpf: Add mptcp subflow subtest" - set limits Geliang Tang
2024-07-30  9:04 ` Matthieu Baerts
2024-07-30  9:14   ` Geliang Tang
2024-07-30  9:15 ` MPTCP CI

This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.